diff src/linuxplay.c @ 380:8626e4521993 r21-2-5

Import from CVS: tag r21-2-5
author cvs
date Mon, 13 Aug 2007 11:07:10 +0200
parents d883f39b8495
children 74fd4e045ea6
line wrap: on
line diff
--- a/src/linuxplay.c	Mon Aug 13 11:06:08 2007 +0200
+++ b/src/linuxplay.c	Mon Aug 13 11:07:10 2007 +0200
@@ -820,7 +820,7 @@
     perror("SNDCTL_DSP_SYNC");
     return(0); }
 
   /* Initialize sound hardware with prefered parameters */
 
   /* If the sound hardware cannot support 16 bit format or requires a
      different byte sex then try to drop to 8 bit format */
@@ -993,9 +993,8 @@
       return; }
 
   /* The VoxWare-SDK discourages opening /dev/audio; opening /dev/dsp and
-     properly intializing it via ioctl() is prefered */
-  if ((audio_fd=open(audio_dev,
-		     (O_WRONLY|O_NDELAY),0)) < 0) {
+     properly initializing it via ioctl() is preferred */
+  if ((audio_fd=open(audio_dev, O_WRONLY | O_NONBLOCK, 0)) < 0) {
     perror(audio_dev);
     if (mix_fd > 0 && mix_fd != audio_fd) { close(mix_fd); mix_fd = -1; }
     return; }
@@ -820,7 +820,7 @@
     return(0); }
 
-  /* Initialize sound hardware with prefered parameters */
+  /* Initialize sound hardware with preferred parameters */
 
   /* If the sound hardware cannot support 16 bit format or requires a